===========
mkbasicauth
===========

Command to generate credential for Basic authorization

.. code-block:: console

    $ mkbasicauth
    username:username
    password:
    dXNlcm5hbWU6cGFzc3dvcmQ=
    $ 
